@@ -2,14 +2,14 @@ from openapi_schema_validator._format import oas30_format_checker
 from openapi_schema_validator._format import oas31_format_checker
 from openapi_schema_validator.shortcuts import validate
 from openapi_schema_validator.validators import OAS30ReadValidator
-from openapi_schema_validator.validators import OAS30WriteValidator
 from openapi_schema_validator.validators import OAS30Validator
+from openapi_schema_validator.validators import OAS30WriteValidator
 from openapi_schema_validator.validators import OAS31Validator
 
 __author__ = "Artur Maciag"
 __email__ = "maciag.artur@gmail.com"
-__version__ = "0.4.2"
-__url__ = "https://github.com/p1c2u/openapi-schema-validator"
+__version__ = "0.4.4"
+__url__ = "https://github.com/python-openapi/openapi-schema-validator"
 __license__ = "3-clause BSD License"
 
 __all__ = [
